@@ -98,6 +98,9 @@ typedef struct _MHW_VDBOX_VDENC_CMD1_PARAMS
     uint8_t                                *pucVdencHmeMvCosts;
     uint8_t                                *pucVdencModeCosts;
     void                                   *pInputParams;
+    uint16_t                                usSADQPLambda = 0;
+    uint16_t                                usRDQPLambda = 0;
+    bool                                    bHevcVisualQualityImprovement = false;  //!< VQI enable flag
 } MHW_VDBOX_VDENC_CMD1_PARAMS, *PMHW_VDBOX_VDENC_CMD1_PARAMS;
 
 struct MHW_VDBOX_VDENC_CMD2_STATE
@@ -122,18 +125,20 @@ struct MHW_VDBOX_VDENC_CMD2_STATE
     PMHW_VDBOX_VP9_SEGMENT_STATE            pVp9SegmentState = nullptr;
     PCODEC_VP9_ENCODE_SEQUENCE_PARAMS       pVp9EncSeqParams = nullptr;
     bool                                    bPrevFrameSegEnabled;
-    uint8_t                                 temporalMVpEnable = 0;
-    uint8_t                                 ucNumRefIdxL0ActiveMinus1 = 0;
     bool                                    bDynamicScalingEnabled = false;
+    bool                                    temporalMVpEnable = false;
 
     // Common
+    uint8_t                                 ucNumRefIdxL0ActiveMinus1 = 0;
+    uint8_t                                 ucNumRefIdxL1ActiveMinus1 = 0;
     uint16_t                                usSADQPLambda = 0;
     uint16_t                                usRDQPLambda = 0;
     bool                                    bPakOnlyMultipassEnable = false;
     void                                    *pInputParams = nullptr;
+    bool                                    bHevcVisualQualityImprovement = false;  //!< VQI enable flag
     virtual ~MHW_VDBOX_VDENC_CMD2_STATE() {}
 };
-using PMHW_VDBOX_VDENC_CMD2_STATE = MHW_VDBOX_VDENC_CMD2_STATE *;
+using PMHW_VDBOX_VDENC_CMD2_STATE = std::shared_ptr<MHW_VDBOX_VDENC_CMD2_STATE>;
 
 struct MHW_VDBOX_VDENC_WALKER_STATE_PARAMS
 {
@@ -150,13 +155,6 @@ struct MHW_VDBOX_VDENC_WALKER_STATE_PARAMS
 };
 using PMHW_VDBOX_VDENC_WALKER_STATE_PARAMS = MHW_VDBOX_VDENC_WALKER_STATE_PARAMS * ;
 
-
-struct MHW_VDBOX_VDENC_AVC_SLICE_STATE_PARAMS
-{
-    PCODEC_AVC_ENCODE_SLICE_PARAMS          pAvcSlcParams = nullptr;
-};
-using PMHW_VDBOX_VDENC_AVC_SLICE_STATE_PARAMS = std::shared_ptr<MHW_VDBOX_VDENC_AVC_SLICE_STATE_PARAMS>;
-
 //!  MHW Vdbox Vdenc interface
 /*!
 This class defines the interfaces for constructing Vdbox Vdenc commands across all platforms
@@ -286,6 +284,14 @@ public:
     //!
     virtual uint32_t GetVdencAvcImgStateSize() = 0;
 
+    //!
+    //! \brief    get Vdenc cost state size
+    //!
+    //! \return   uint32_t
+    //!           Vdenc cost state size got
+    //!
+    virtual uint32_t GetVdencAvcCostStateSize() = 0;
+
     //!
     //! \brief    get cmd1
     //!
@@ -433,6 +439,7 @@ public:
         uint8_t                              numSurfaces) = 0;
 
     virtual MOS_STATUS AddVdencAvcCostStateCmd(
+        PMOS_COMMAND_BUFFER       cmdBuffer,
         PMHW_BATCH_BUFFER         batchBuffer,
         PMHW_VDBOX_AVC_IMG_PARAMS params)
     {
@@ -517,8 +524,8 @@ public:
         PMHW_VDBOX_VDENC_WEIGHT_OFFSET_PARAMS   params) = 0;
 
     virtual MOS_STATUS AddVdencSliceStateCmd(
-        PMOS_COMMAND_BUFFER                     cmdBuffer,
-        PMHW_VDBOX_VDENC_AVC_SLICE_STATE_PARAMS params)
+        PMOS_COMMAND_BUFFER        cmdBuffer,
+        PMHW_VDBOX_AVC_SLICE_STATE params)
     {
         return MOS_STATUS_SUCCESS;
     }
