@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2018, Intel Corporation
+* Copyright (c) 2009-2019, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -45,6 +45,8 @@
 #include "mos_os_specific.h"
 #include "mos_os_virtualengine_specific.h"
 
+#include "mos_oca_interface.h"
+
 #define MOS_NAL_UNIT_LENGTH                 4
 #define MOS_NAL_UNIT_STARTCODE_LENGTH       3
 #define MOS_MAX_PATH_LENGTH                 256
@@ -63,18 +65,26 @@
     ((GpuContext) == MOS_GPU_CONTEXT_VIDEO4)        || \
     ((GpuContext) == MOS_GPU_CONTEXT_VDBOX2_VIDEO)  || \
     ((GpuContext) == MOS_GPU_CONTEXT_VDBOX2_VIDEO2) || \
-    ((GpuContext) == MOS_GPU_CONTEXT_VDBOX2_VIDEO3)    \
+    ((GpuContext) == MOS_GPU_CONTEXT_VDBOX2_VIDEO3) || \
+    ((GpuContext) == MOS_GPU_CONTEXT_VIDEO5)        || \
+    ((GpuContext) == MOS_GPU_CONTEXT_VIDEO6)        || \
+    ((GpuContext) == MOS_GPU_CONTEXT_VIDEO7)           \
 )
 
-#define MOS_RCS_ENGINE_USED(GpuContext) (              \
-    ((GpuContext) == MOS_GPU_CONTEXT_RENDER)        || \
-    ((GpuContext) == MOS_GPU_CONTEXT_RENDER2)       || \
-    ((GpuContext) == MOS_GPU_CONTEXT_RENDER3)       || \
-    ((GpuContext) == MOS_GPU_CONTEXT_RENDER4)       || \
-    ((GpuContext) == MOS_GPU_CONTEXT_COMPUTE)       || \
-    ((GpuContext) == MOS_GPU_CONTEXT_CM_COMPUTE)        \
+#define MOS_RCS_ENGINE_USED(GpuContext) (                 \
+    ((GpuContext) == MOS_GPU_CONTEXT_RENDER)           || \
+    ((GpuContext) == MOS_GPU_CONTEXT_RENDER2)          || \
+    ((GpuContext) == MOS_GPU_CONTEXT_RENDER3)          || \
+    ((GpuContext) == MOS_GPU_CONTEXT_RENDER4)          || \
+    ((GpuContext) == MOS_GPU_CONTEXT_COMPUTE)          || \
+    ((GpuContext) == MOS_GPU_CONTEXT_CM_COMPUTE)       || \
+    ((GpuContext) == MOS_GPU_CONTEXT_COMPUTE_RA)       || \
+    ((GpuContext) == MOS_GPU_CONTEXT_RENDER_RA)           \
 )
 
+#define MOS_BCS_ENGINE_USED(GpuContext) (             \
+    ((GpuContext) == MOS_GPU_CONTEXT_BLT))
+
 #if MOS_MEDIASOLO_SUPPORTED
 #define MOS_VECS_ENGINE_USED(GpuContext) (             \
     ((GpuContext) == MOS_GPU_CONTEXT_VEBOX)         || \
@@ -90,6 +100,7 @@
 #define MOS_COMMAND_BUFFER_RENDER_ENGINE   "CS"
 #define MOS_COMMAND_BUFFER_VIDEO_ENGINE    "VCS"
 #define MOS_COMMAND_BUFFER_VEBOX_ENGINE    "VECS"
+#define MOS_COMMAND_BUFFER_RTE_ENGINE      "RTE"
 #define MOS_COMMAND_BUFFER_PLATFORM_LEN    4
 #endif // MOS_COMMAND_BUFFER_DUMP_SUPPORTED
 
@@ -157,11 +168,15 @@ typedef enum _MOS_FORCE_VDBOX
 //!
 typedef enum _MOS_FORCE_VEBOX
 {
-    MOS_FORCE_VEBOX_NONE = 0,
-    MOS_FORCE_VEBOX_1 = 0x0001,
-    MOS_FORCE_VEBOX_2 = 0x0002,
+    MOS_FORCE_VEBOX_NONE    = 0,
+    MOS_FORCE_VEBOX_1       = 0x0001,
+    MOS_FORCE_VEBOX_2       = 0x0002,
+    MOS_FORCE_VEBOX_3       = 0x0003,
+    MOS_FORCE_VEBOX_4       = 0x0004,
     // For scalability case
-    MOS_FORCE_VEBOX_1_2 = 0x0012
+    MOS_FORCE_VEBOX_1_2     = 0x0012,
+    MOS_FORCE_VEBOX_1_2_3   = 0x0123,
+    MOS_FORCE_VEBOX_1_2_3_4 = 0x1234
 } MOS_FORCE_VEBOX;
 
 #define MOS_FORCEVEBOX_VEBOXID_BITSNUM              4 //each VEBOX ID occupies 4 bits see defintion MOS_FORCE_VEBOX
@@ -194,6 +209,7 @@ typedef struct _MOS_COMMAND_BUFFER_ATTRIBUTES
     uint32_t                    dwMediaFrameTrackingAddrOffset;
     MOS_RESOURCE                resMediaFrameTrackingSurface;
     int32_t                     bUmdSSEUEnable;
+    int32_t                     bFrequencyBoost;
     void*                       pAttriVe;
 } MOS_COMMAND_BUFFER_ATTRIBUTES, *PMOS_COMMAND_BUFFER_ATTRIBUTES;
 
@@ -224,6 +240,7 @@ typedef struct _MOS_COMMAND_BUFFER
     MOS_VDBOX_NODE_IND  iVdboxNodeIndex;            //!< Which VDBOX buffer is binded to
 
     MOS_COMMAND_BUFFER_ATTRIBUTES Attributes;       //!< Attributes for the command buffer to be provided to KMD at submission
+    MOS_OCA_BUFFER_HANDLE hOcaBuf;                  //!< Oca buffer handle for current command
 } MOS_COMMAND_BUFFER;
 
 //!
@@ -307,7 +324,7 @@ typedef struct _MOS_PATCH_ENTRY_PARAMS
     uint32_t      uiAllocationIndex;
     uint32_t      uiResourceOffset;  //!< resource offset
     uint32_t      uiPatchOffset;     //!< patch offset
-    bool          bWrite;            //!< is write operation
+    uint32_t      bWrite;            //!< is write operation
     int32_t       bUpperBoundPatch;  //!< is upper bound patch
     MOS_HW_COMMAND              HwCommandType;     //!< hw cmd type
     uint32_t                    forceDwordOffset;  //!< force dword offset
@@ -322,7 +339,7 @@ typedef struct _MOS_GPUCTX_CREATOPTIONS MOS_GPUCTX_CREATOPTIONS, *PMOS_GPUCTX_CR
 struct _MOS_GPUCTX_CREATOPTIONS
 {
     uint32_t  CmdBufferNumScale;
-
+    uint32_t  RAMode;
     //For slice shutdown
     union
     {
@@ -337,12 +354,10 @@ struct _MOS_GPUCTX_CREATOPTIONS
         uint32_t SSEUValue;
     };
 
-    bool  runAloneMode;
-
-    _MOS_GPUCTX_CREATOPTIONS()
-            : CmdBufferNumScale(MOS_GPU_CONTEXT_CREATE_DEFAULT),
-              SSEUValue(0),
-              runAloneMode(false) {}
+    _MOS_GPUCTX_CREATOPTIONS() : 
+        CmdBufferNumScale(MOS_GPU_CONTEXT_CREATE_DEFAULT),
+        RAMode(0),
+        SSEUValue(0){}
 
     virtual ~_MOS_GPUCTX_CREATOPTIONS(){}
 };
@@ -938,6 +953,11 @@ typedef struct _MOS_INTERFACE
         PMOS_RESOURCE               pOsResource,
         int32_t                     bHintOn);
 
+    MOS_STATUS (* pfnGetMemoryCompressionFormat) (
+        PMOS_INTERFACE              pOsInterface,
+        PMOS_RESOURCE               pOsResource,
+        uint32_t                    *pResMmcFormat);
+
     MOS_STATUS (* pfnCreateVideoNodeAssociation)(
         PMOS_INTERFACE              pOsInterface,
         int32_t                     bSetVideoNode,
@@ -1042,10 +1062,14 @@ typedef struct _MOS_INTERFACE
     int32_t                         bUseHwSemaForResSyncInVE;                     //!< Flag to indicate if UMD need to send HW sema cmd under this OS when there is a resource sync need with Virtual Engine interface 
     PMOS_VIRTUALENGINE_INTERFACE    pVEInterf;
     bool                            ctxBasedScheduling;                           //!< Flag to indicate if context based scheduling enabled for virtual engine, that is VE2.0.
+    bool                            multiNodeScaling;                             //!< Flag to indicate if multi-node scaling is enabled for virtual engine, that is VE3.0.
     bool                            veDefaultEnable = true;                       //!< Flag to indicate if virtual engine is enabled by default
 
     MOS_CMD_BUF_ATTRI_VE            bufAttriVe[MOS_GPU_CONTEXT_MAX];
 
+    MOS_STATUS (*pfnCheckVirtualEngineSupported)(
+        PMOS_INTERFACE              pOsInterface);
+
 #if MOS_MEDIASOLO_SUPPORTED
     int32_t                         bSupportMediaSoloVirtualEngine;               //!< Flag to indicate if MediaSolo uses VE solution in cmdbuffer submission.
 #endif // MOS_MEDIASOLO_SUPPORTED
@@ -1157,6 +1181,9 @@ struct _MOS_GPUCTX_CREATOPTIONS_ENHANCED : public _MOS_GPUCTX_CREATOPTIONS
 #define MOS_VE_CTXBASEDSCHEDULING_SUPPORTED(pOsInterface) \
     (pOsInterface ? pOsInterface->ctxBasedScheduling : false)
 
+#define MOS_VE_MULTINODESCALING_SUPPORTED(pOsInterface) \
+    (pOsInterface ? pOsInterface->multiNodeScaling : false)
+
 #if MOS_MEDIASOLO_SUPPORTED
 #define MOS_MEDIASOLO_VE_SUPPORTED(pOsInterface) \
     (pOsInterface ? pOsInterface->bSupportMediaSoloVirtualEngine : false)
