@@ -180,7 +180,8 @@ void VpHal_DdiReportFeatureMode(
 
     // Report Scaling mode
     pConfigValues->dwCurrentScalingMode =
-        (pReport->ScalingMode == VPHAL_SCALING_AVS) ? VPDDI_ADVANCEDSCALING : VPDDI_SCALING;
+        (pReport->ScalingMode == VPHAL_SCALING_AVS) ? VPDDI_ADVANCEDSCALING :
+            (pReport->ScalingMode > VPHAL_SCALING_AVS) ? VPDDI_SUPERRESOLUTIONSCALING : VPDDI_SCALING;
 
     // Report Output Pipe
     pConfigValues->dwCurrentOutputPipeMode = pReport->OutputPipeMode;
