@@ -1191,8 +1191,6 @@ public:
         cmd.DW22.Largembsizeinword                   = 0xff;
         cmd.DW27.MaxHmvR                             = 0x2000;
         cmd.DW27.MaxVmvR                             = 0x200;
-        cmd.DW33.MaxQp                               = 0x33;
-        cmd.DW33.MinQp                               = 0x0a;
         cmd.DW33.Maxdeltaqp                          = 0x0f;
 
         // initialize for P frame
@@ -1319,6 +1317,19 @@ public:
             cmd.DW21.QpAdjustmentForRollingI          = avcPicParams->IntraRefreshQPDelta;
         }
 
+        // Setting MinMaxQP values if they are presented
+        if (avcPicParams->ucMaximumQP && avcPicParams->ucMinimumQP)
+        {
+            cmd.DW33.MaxQp = avcPicParams->ucMaximumQP;
+            cmd.DW33.MinQp = avcPicParams->ucMinimumQP;
+        }
+        else
+        {
+            // Set default values
+            cmd.DW33.MaxQp = 0x33;
+            cmd.DW33.MinQp = 0x0a;
+        }
+
         // VDEnc CQP case ROI settings, BRC ROI will be handled in HuC FW
         if (!params->bVdencBRCEnabled && avcPicParams->NumROI)
         {
@@ -1471,7 +1482,7 @@ public:
                     uint32_t numOfLCU                = widthInLCU*(frameHeightInLCU + 1);
                     uint32_t maxNumCUInLCU           = (64 / 8)*(64 / 8); //max LCU size is 64, min Cu size is 8
 
-                    uint32_t tileLCUStreamOutByteOffset = 2 * 4 * ((numOfLCU * 5) + (numOfLCU*maxNumCUInLCU * 8));
+                    uint32_t tileLCUStreamOutByteOffset = 2 * BYTES_PER_DWORD * numOfLCU * (NUM_PAK_DWS_PER_LCU + maxNumCUInLCU * NUM_DWS_PER_CU);
                     cmd.DW9.TileLcuStreamOutOffset      = MOS_ROUNDUP_DIVIDE(tileLCUStreamOutByteOffset, MHW_CACHELINE_SIZE);
                 }
             }
