@@ -1143,6 +1143,7 @@ public:
     //!             following formats: \n
     //!                 CM_SURFACE_FORMAT_A16B16G16R16 \n
     //!                 CM_SURFACE_FORMAT_A16B16G16R16F \n
+    //!                 CM_SURFACE_FORMAT_R32G32B32A32F \n
     //!                 CM_SURFACE_FORMAT_A8 \n
     //!                 CM_SURFACE_FORMAT_A8R8G8B8 \n
     //!                 CM_SURFACE_FORMAT_YUY2 \n
@@ -1622,6 +1623,7 @@ public:
     //!             surface's formats, for now, we support following: \n
     //!                 CM_SURFACE_FORMAT_A16B16G16R16 \n
     //!                 CM_SURFACE_FORMAT_A16B16G16R16F \n
+    //!                 CM_SURFACE_FORMAT_R32G32B32A32F \n
     //!                 CM_SURFACE_FORMAT_A8 \n
     //!                 CM_SURFACE_FORMAT_A8R8G8B8 \n
     //!                 CM_SURFACE_FORMAT_YUY2 \n
@@ -1733,7 +1735,7 @@ public:
     //!             struct CM_QUEUE_CREATE_OPTION
     //!             {
     //!                 CM_QUEUE_TYPE QueueType : 3;
-    //!                 bool RunAloneMode       : 1;
+    //!                 bool RA       : 1;
     //!                 unsigned int Reserved0  : 3;
     //!                 bool UserGPUContext     : 1;
     //!                 unsigned int GPUContext : 8;
@@ -1753,7 +1755,7 @@ public:
     //!             };
     //!             \endcode
     //!             \n
-    //!             <b>RunAloneMode</b> decides if the queue will occupy GPU
+    //!             <b>RAMode</b> decides if the queue will occupy GPU
     //!             exclusively during execution.\n
     //!             <b>UserGPUContext</b> indicates if the user wants to
     //!             provide an existing MOS GPU Context.\n
@@ -1814,6 +1816,37 @@ public:
     //!
     CM_RT_API virtual int32_t UpdateSurface2D(PMOS_RESOURCE mosResource,
                                               CmSurface2D* &surface) = 0;
+
+    //!
+    //! \brief      Creates a CmSampler8x8 surface from Surface2D alias.
+    //! \details    Creates a CmSampler8x8 surface by using the given 2D surface
+    //!             alias.
+    //!             No extra surface is actually created. A SurfaceIndex
+    //!             object is created instead, which is passed to CM kernel
+    //!             function (genx_main) as an argument to indicate the surface
+    //!             for AVS.
+    //! \param      [in] originalSurface
+    //!             Pointer to the original CmSurface2D object.
+    //! \param      [in] aliasIndex
+    //!             Surface alias upon which the output surface index is
+    //!             created.
+    //! \param      [in] addressControl
+    //!             Enumerator specifying address control mode used by AVS.
+    //! \param      [out] sampler8x8SurfaceIndex
+    //!             Sampler8x8 surface index created by this function.
+    //! \retval     CM_SUCCESS if the CmSampler8x8 surface is successfully
+    //!             created.
+    //! \retval     CM_EXCEED_SURFACE_AMOUNT if there are too many surfaces,
+    //!             exceeding the maximum limit,
+    //! \retval     CM_OUT_OF_HOST_MEMORY if out of host memory,
+    //! \retval     CM_FAILURE otherwise.
+    //!
+    CM_RT_API virtual int32_t
+    CreateSampler8x8SurfaceFromAlias(
+        CmSurface2D *originalSurface,
+        SurfaceIndex *aliasIndex,
+        CM_SURFACE_ADDRESS_CONTROL_MODE addressControl,
+        SurfaceIndex* &sampler8x8SurfaceIndex) = 0;
 };
 }; //namespace
 
