@@ -645,6 +645,13 @@ VAStatus DdiMediaDecode::EndPicture(
     VAContextID      context)
 {
     DDI_FUNCTION_ENTER();
+
+    if (m_ddiDecodeCtx->bDecodeModeReported == false)
+    {
+        ReportDecodeMode(m_ddiDecodeCtx->wMode);
+        m_ddiDecodeCtx->bDecodeModeReported = true;
+    }
+
     DDI_CHK_RET(InitDecodeParams(ctx,context),"InitDecodeParams failed!");
 
     DDI_CHK_RET(SetDecodeParams(), "SetDecodeParams failed!");
@@ -1034,3 +1041,46 @@ void DdiMediaDecode::GetDummyReferenceFromDPB(
         decoder->GetDummyReference()->OsResource = dummyReference.OsResource;
     }
 }
+
+void DdiMediaDecode::ReportDecodeMode(
+    uint16_t      wMode)
+ {
+    MOS_USER_FEATURE_VALUE_WRITE_DATA userFeatureWriteData;
+    MOS_ZeroMemory(&userFeatureWriteData, sizeof(userFeatureWriteData));
+    userFeatureWriteData.Value.i32Data = wMode;
+    switch (wMode)
+    {
+        case CODECHAL_DECODE_MODE_MPEG2IDCT:
+        case CODECHAL_DECODE_MODE_MPEG2VLD:
+            userFeatureWriteData.ValueID = __MEDIA_USER_FEATURE_VALUE_DECODE_MPEG2_MODE_ID;
+            MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1);
+            break;
+        case CODECHAL_DECODE_MODE_VC1IT:
+        case CODECHAL_DECODE_MODE_VC1VLD:
+            userFeatureWriteData.ValueID = __MEDIA_USER_FEATURE_VALUE_DECODE_VC1_MODE_ID;
+            MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1);
+            break;
+        case CODECHAL_DECODE_MODE_AVCVLD:
+            userFeatureWriteData.ValueID = __MEDIA_USER_FEATURE_VALUE_DECODE_AVC_MODE_ID;
+            MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1);
+            break;
+        case CODECHAL_DECODE_MODE_JPEG:
+            userFeatureWriteData.ValueID = __MEDIA_USER_FEATURE_VALUE_DECODE_JPEG_MODE_ID;
+            MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1);
+            break;
+        case CODECHAL_DECODE_MODE_VP8VLD:
+            userFeatureWriteData.ValueID = __MEDIA_USER_FEATURE_VALUE_DECODE_VP8_MODE_ID;
+            MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1);
+            break;
+        case CODECHAL_DECODE_MODE_HEVCVLD:
+            userFeatureWriteData.ValueID = __MEDIA_USER_FEATURE_VALUE_DECODE_HEVC_MODE_ID;
+            MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1);
+            break;
+        case CODECHAL_DECODE_MODE_VP9VLD:
+            userFeatureWriteData.ValueID = __MEDIA_USER_FEATURE_VALUE_DECODE_VP9_MODE_ID;
+            MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1);
+            break;
+        default:
+            break;
+    }
+ }
